@@ -211,6 +211,11 @@ dbms_random_string(PG_FUNCTION_ARGS)
 				 errmsg("an argument is NULL")));
 
 	option = text_to_cstring(PG_GETARG_TEXT_P(0));
+	if (strlen(option) != 1)
+		ereport(ERROR,
+				(errcode(ERRCODE_STRING_DATA_RIGHT_TRUNCATION),
+				 errmsg("this first parameter value is more than 1 characters long")));
+
 	len = PG_GETARG_INT32(1);
 
 	switch (option[0])
@@ -240,15 +245,12 @@ dbms_random_string(PG_FUNCTION_ARGS)
 			charset = printable;
 			chrset_size = strlen(printable);
 			break;
-			
+
+		/* Otherwise the returning string is in uppercase alpha characters. */
 		default:
-			ereport(ERROR,
-				(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-				 errmsg("unknown option '%s'", option),
-				 errhint("available option \"aAlLuUxXpP\"")));
-			/* be compiler a quiete */
-			charset = NULL;
-			chrset_size = 0;
+			charset = upper_only;
+			chrset_size = strlen(upper_only);
+			break;
 	}
 
 	PG_RETURN_TEXT_P(random_string(charset, chrset_size, len));
@@ -296,14 +298,24 @@ dbms_random_value_range(PG_FUNCTION_ARGS)
 	float8 result;
 
 	if (low > high)
-		PG_RETURN_NULL();
+	{
+		float8 aux;
 
-	result = ((double) rand() / ((double) RAND_MAX + 1)) * ( high -  low) + low;
+		aux = low;
+		low = high; high = aux;
+	}
+
+	/*
+	 * in the case high == low, we don't need to calculate result, but then
+	 * we change order of calls rand() functions, and this should break
+	 * customer's regress tests. To minimize impact on regress tests, we use same formula
+	 * for this case too.
+	 */
+	result = ((double) rand() / ((double) RAND_MAX + 1)) * (high -  low) + low;
 
 	PG_RETURN_FLOAT8(result);
 }
 
-
 /*
  * Lower tail quantile for standard normal distribution function.
  *
